@@ -1,3 +1,17 @@
+# Copyright 2021 Google LLC
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import re
 import subprocess
@@ -48,7 +62,7 @@ def create_or_return_space(space_name, parent_id, sdk):
 def get_gzr_creds(ini, env):
     ini = parse_ini.read_ini(ini)
     env_record = ini[env]
-    host, port = env_record["base_url"].lstrip("https://").split(":")
+    host, port = env_record["base_url"].replace("https://", "").split(":")
     client_id = env_record["client_id"]
     client_secret = env_record["client_secret"]
     verify_ssl = env_record["verify_ssl"]
@@ -56,35 +70,6 @@ def get_gzr_creds(ini, env):
     return (host, port, client_id, client_secret, verify_ssl)
 
 
-def export_spaces(env, ini, path, debug=False):
-    host, port, client_id, client_secret, verify_ssl = get_gzr_creds(ini, env)
-
-    gzr_command = [
-        "gzr",
-        "space",
-        "export",
-        "1",
-        "--dir",
-        path,
-        "--host",
-        host,
-        "--port",
-        port,
-        "--client-id",
-        client_id,
-        "--client-secret",
-        client_secret
-    ]
-
-    # config parser returns a string - easier to parse that than convert to a bool
-    if verify_ssl == "False":
-        gzr_command.append("--no-verify-ssl")
-    if debug:
-        gzr_command.append("--debug")
-
-    subprocess.run(gzr_command)
-
-
 def import_content(content_type, content_json, space_id, env, ini, debug=False):
     assert content_type in ["dashboard", "look"], "Unsupported Content Type"
     host, port, client_id, client_secret, verify_ssl = get_gzr_creds(ini, env)
@@ -125,6 +110,11 @@ def import_content(content_type, content_json, space_id, env, ini, debug=False):
     if debug:
         gzr_command.append("--debug")
 
+    # if we're running on windows we need to appropriately call the command-line arg"
+    if os.name == "nt":
+        win_exec = ["cmd.exe", "/c"]
+        gzr_command = win_exec + gzr_command
+
     subprocess.run(gzr_command)
 
 
@@ -301,19 +291,15 @@ def main(args):
         if not args.target_folder.endswith(os.sep):
             args.target_folder += os.sep
 
-    if args.export:
-        logger.info("Pulling content from dev", extra={"env": args.env, "pull_location": args.export})
-        export_spaces(args.env, args.ini, args.export, args.debug)
-    else:
-        sdk = get_client(args.ini, args.env)
-        send_content(
-            sdk,
-            args.env,
-            args.ini,
-            args.target_folder,
-            args.folders,
-            args.dashboards,
-            args.looks,
-            args.recursive,
-            args.debug
-        )
+    sdk = get_client(args.ini, args.env)
+    send_content(
+        sdk,
+        args.env,
+        args.ini,
+        args.target_folder,
+        args.folders,
+        args.dashboards,
+        args.looks,
+        args.recursive,
+        args.debug
+    )
